const mongoose = require('mongoose');

// Variant Schema
const variantSchema = new mongoose.Schema({
  title: { type: String, required: true, default: "Default Title" },
  price: { type: Number, required: true, default: 0.00 },
  position: { type: Number, default: 1 },
  inventory_policy: { type: String, default: "deny" },
  compare_at_price: { type: Number, default: null },
  option1: { type: String, default: "Default Title" },
  option2: { type: String, default: null },
  option3: { type: String, default: null },
  taxable: { type: Boolean, default: true },
  barcode: { type: String, default: null },
  fulfillment_service: { type: String, default: "manual" },
  grams: { type: Number, default: 0 },
  inventory_management: { type: String, default: null },
  requires_shipping: { type: Boolean, default: true },
  sku: { type: String, default: "" },
  weight: { type: Number, default: 0 },
  weight_unit: { type: String, default: "kg" },
  inventory_item_id: { type: Number },
  inventory_quantity: { type: Number, default: 0 },
  old_inventory_quantity: { type: Number, default: 0 },
  image_id: { type: Number, default: null },
  admin_graphql_api_id: { type: String, required: true }
});

// Option Schema
const optionSchema = new mongoose.Schema({
  name: { type: String, required: true },
  position: { type: Number, default: 1 },
  values: [{ type: String }]
});

// Main Product Schema with timestamps
const productSchema = new mongoose.Schema({
  title: { type: String, required: true, trim: true },
  body_html: { type: String, default: null },
  vendor: { type: String, default: "" },
  product_type: { type: String, default: "" },
  created_at: { type: Date },
  handle: { type: String },
  updated_at: { type: Date },
  published_at: { type: Date, default: null },
  template_suffix: { type: String, default: null },
  published_scope: { type: String, default: "web" },
  tags: { type: String, default: "" },
  status: { type: String, enum: ['active', 'draft'], default: "active" },
  admin_graphql_api_id: { type: String },
  variants: [variantSchema], // Embedded Variant Schema
  options: [optionSchema],   // Embedded Option Schema
  images: [{ type: String }], // URLs to images
  image: { type: String, default: null } // Default image URL
}, { timestamps: true });

module.exports = mongoose.model('Product', productSchema);
