const axios = require('axios'); // Import Axios
require('dotenv').config(); // Load environment variables from .env

// Function to fetch collections using Axios
const fetchCollections = async () => {
  try {
    // Create headers
    const myHeaders = {
      "Content-Type": "application/json",
      "X-Shopify-Access-Token": process.env.SHOPIFY_ACCESS_TOKEN, // Access token from .env
    };

    // Define GraphQL query
    const graphql = {
      query: `query MyCollections {
        collections(first: 10) {
          nodes {
            id
            title
          }
          pageInfo {
            endCursor
            hasNextPage
            hasPreviousPage
            startCursor
          }
        }
      }`,
      variables: {},
    };

    // Axios request
    const response = await axios.post(
      `https://${process.env.SHOPIFY_STORE_URL}/admin/api/2024-07/graphql.json`, // Store URL from .env
      graphql,
      { headers: myHeaders }
    );

    // Extract data from the response
    const collections = response.data.data.collections.nodes;
    const pageInfo = response.data.data.collections.pageInfo;


    // Return collections and pageInfo
    return {
      collections: collections,
      pageInfo: pageInfo,
    };
  } catch (error) {
    console.error('Error fetching collections:', error.response ? error.response.data : error.message);
    throw new Error('Failed to fetch collections');
  }
};

module.exports = { fetchCollections };
